==> gitea-1.24.7.tar.gz: gitea-src-1.24.7/routers/api/v1/swagger/options.go <==
// Copyright 2017 The Gitea Authors. All rights reserved.
// SPDX-License-Identifier: MIT

package swagger

import (
	api "code.gitea.io/gitea/modules/structs"
	"code.gitea.io/gitea/services/forms"
)

// not actually a response, just a hack to get go-swagger to include definitions
// of the various XYZOption structs

// parameterBodies
// swagger:response parameterBodies
type swaggerParameterBodies struct {
	// in:body
	AddCollaboratorOption api.AddCollaboratorOption

	// in:body
	CreateEmailOption api.CreateEmailOption
	// in:body
	DeleteEmailOption api.DeleteEmailOption

	// in:body
	CreateHookOption api.CreateHookOption
	// in:body
	EditHookOption api.EditHookOption

	// in:body
	EditGitHookOption api.EditGitHookOption

	// in:body
	CreateIssueOption api.CreateIssueOption
	// in:body
	EditIssueOption api.EditIssueOption
	// in:body
	EditDeadlineOption api.EditDeadlineOption

	// in:body
	CreateIssueCommentOption api.CreateIssueCommentOption
	// in:body
	EditIssueCommentOption api.EditIssueCommentOption
	// in:body
	IssueMeta api.IssueMeta

	// in:body
	IssueLabelsOption api.IssueLabelsOption

	// in:body
	CreateKeyOption api.CreateKeyOption

	// in:body
	RenameUserOption api.RenameUserOption

	// in:body
	CreateLabelOption api.CreateLabelOption
	// in:body
	EditLabelOption api.EditLabelOption

	// in:body
	MarkupOption api.MarkupOption
	// in:body
	MarkdownOption api.MarkdownOption

	// in:body
	CreateMilestoneOption api.CreateMilestoneOption
	// in:body
	EditMilestoneOption api.EditMilestoneOption

	// in:body
	CreateOrgOption api.CreateOrgOption
	// in:body
	EditOrgOption api.EditOrgOption

	// in:body
	CreatePullRequestOption api.CreatePullRequestOption
	// in:body
	EditPullRequestOption api.EditPullRequestOption
	// in:body
	MergePullRequestOption forms.MergePullRequestForm

	// in:body
	CreateReleaseOption api.CreateReleaseOption
	// in:body
	EditReleaseOption api.EditReleaseOption

	// in:body
	CreateRepoOption api.CreateRepoOption
	// in:body
	EditRepoOption api.EditRepoOption
	// in:body
	UpdateBranchRepoOption api.UpdateBranchRepoOption
	// in:body
	TransferRepoOption api.TransferRepoOption
	// in:body
	CreateForkOption api.CreateForkOption
	// in:body
	GenerateRepoOption api.GenerateRepoOption

	// in:body
	CreateStatusOption api.CreateStatusOption

	// in:body
	CreateTeamOption api.CreateTeamOption
	// in:body
	EditTeamOption api.EditTeamOption

	// in:body
	AddTimeOption api.AddTimeOption

	// in:body
	CreateUserOption api.CreateUserOption

	// in:body
	EditUserOption api.EditUserOption

	// in:body
	EditAttachmentOptions api.EditAttachmentOptions

	// in:body
	GetFilesOptions api.GetFilesOptions

	// in:body
	ChangeFilesOptions api.ChangeFilesOptions

	// in:body
	CreateFileOptions api.CreateFileOptions

	// in:body
	UpdateFileOptions api.UpdateFileOptions

	// in:body
	DeleteFileOptions api.DeleteFileOptions

	// in:body
	CommitDateOptions api.CommitDateOptions

	// in:body
	RepoTopicOptions api.RepoTopicOptions

	// in:body
	EditReactionOption api.EditReactionOption

	// in:body
	CreateBranchRepoOption api.CreateBranchRepoOption

	// in:body
	CreateBranchProtectionOption api.CreateBranchProtectionOption

	// in:body
	EditBranchProtectionOption api.EditBranchProtectionOption

	// in:body
	UpdateBranchProtectionPriories api.UpdateBranchProtectionPriories

	// in:body
	CreateOAuth2ApplicationOptions api.CreateOAuth2ApplicationOptions

	// in:body
	CreatePullReviewOptions api.CreatePullReviewOptions

	// in:body
	CreatePullReviewComment api.CreatePullReviewComment

	// in:body
	SubmitPullReviewOptions api.SubmitPullReviewOptions

	// in:body
	DismissPullReviewOptions api.DismissPullReviewOptions

	// in:body
	MigrateRepoOptions api.MigrateRepoOptions

	// in:body
	PullReviewRequestOptions api.PullReviewRequestOptions

	// in:body
	CreateTagOption api.CreateTagOption

	// in:body
	CreateTagProtectionOption api.CreateTagProtectionOption

	// in:body
	EditTagProtectionOption api.EditTagProtectionOption

	// in:body
	CreateAccessTokenOption api.CreateAccessTokenOption

	// in:body
	UserSettingsOptions api.UserSettingsOptions

	// in:body
	CreateWikiPageOptions api.CreateWikiPageOptions

	// in:body
	CreatePushMirrorOption api.CreatePushMirrorOption

	// in:body
	UpdateUserAvatarOptions api.UpdateUserAvatarOption

	// in:body
	UpdateRepoAvatarOptions api.UpdateRepoAvatarOption

	// in:body
	CreateOrUpdateSecretOption api.CreateOrUpdateSecretOption

	// in:body
	UserBadgeOption api.UserBadgeOption

	// in:body
	CreateVariableOption api.CreateVariableOption

	// in:body
	RenameOrgOption api.RenameOrgOption

	// in:body
	CreateActionWorkflowDispatch api.CreateActionWorkflowDispatch

	// in:body
	UpdateVariableOption api.UpdateVariableOption

	// in:body
	LockIssueOption api.LockIssueOption
}

==> gitea-1.25.3.tar.gz: gitea-src-1.25.3/routers/api/v1/swagger/options.go <==
// Copyright 2017 The Gitea Authors. All rights reserved.
// SPDX-License-Identifier: MIT

package swagger

import (
	api "code.gitea.io/gitea/modules/structs"
	"code.gitea.io/gitea/services/forms"
)

// not actually a response, just a hack to get go-swagger to include definitions
// of the various XYZOption structs

// parameterBodies
// swagger:response parameterBodies
type swaggerParameterBodies struct {
	// in:body
	AddCollaboratorOption api.AddCollaboratorOption

	// in:body
	CreateEmailOption api.CreateEmailOption
	// in:body
	DeleteEmailOption api.DeleteEmailOption

	// in:body
	CreateHookOption api.CreateHookOption
	// in:body
	EditHookOption api.EditHookOption

	// in:body
	EditGitHookOption api.EditGitHookOption

	// in:body
	CreateIssueOption api.CreateIssueOption
	// in:body
	EditIssueOption api.EditIssueOption
	// in:body
	EditDeadlineOption api.EditDeadlineOption

	// in:body
	CreateIssueCommentOption api.CreateIssueCommentOption
	// in:body
	EditIssueCommentOption api.EditIssueCommentOption
	// in:body
	IssueMeta api.IssueMeta

	// in:body
	IssueLabelsOption api.IssueLabelsOption

	// in:body
	CreateKeyOption api.CreateKeyOption

	// in:body
	RenameUserOption api.RenameUserOption

	// in:body
	CreateLabelOption api.CreateLabelOption
	// in:body
	EditLabelOption api.EditLabelOption

	// in:body
	MarkupOption api.MarkupOption
	// in:body
	MarkdownOption api.MarkdownOption

	// in:body
	CreateMilestoneOption api.CreateMilestoneOption
	// in:body
	EditMilestoneOption api.EditMilestoneOption

	// in:body
	CreateOrgOption api.CreateOrgOption
	// in:body
	EditOrgOption api.EditOrgOption

	// in:body
	CreatePullRequestOption api.CreatePullRequestOption
	// in:body
	EditPullRequestOption api.EditPullRequestOption
	// in:body
	MergePullRequestOption forms.MergePullRequestForm

	// in:body
	CreateReleaseOption api.CreateReleaseOption
	// in:body
	EditReleaseOption api.EditReleaseOption

	// in:body
	CreateRepoOption api.CreateRepoOption
	// in:body
	EditRepoOption api.EditRepoOption
	// in:body
	RenameBranchRepoOption api.RenameBranchRepoOption
	// in:body
	TransferRepoOption api.TransferRepoOption
	// in:body
	CreateForkOption api.CreateForkOption
	// in:body
	GenerateRepoOption api.GenerateRepoOption

	// in:body
	CreateStatusOption api.CreateStatusOption

	// in:body
	CreateTeamOption api.CreateTeamOption
	// in:body
	EditTeamOption api.EditTeamOption

	// in:body
	AddTimeOption api.AddTimeOption

	// in:body
	CreateUserOption api.CreateUserOption

	// in:body
	EditUserOption api.EditUserOption

	// in:body
	EditAttachmentOptions api.EditAttachmentOptions

	// in:body
	GetFilesOptions api.GetFilesOptions

	// in:body
	ApplyDiffPatchFileOptions api.ApplyDiffPatchFileOptions

	// in:body
	ChangeFilesOptions api.ChangeFilesOptions

	// in:body
	CreateFileOptions api.CreateFileOptions

	// in:body
	UpdateFileOptions api.UpdateFileOptions

	// in:body
	DeleteFileOptions api.DeleteFileOptions

	// in:body
	CommitDateOptions api.CommitDateOptions

	// in:body
	RepoTopicOptions api.RepoTopicOptions

	// in:body
	EditReactionOption api.EditReactionOption

	// in:body
	CreateBranchRepoOption api.CreateBranchRepoOption

	// in:body
	CreateBranchProtectionOption api.CreateBranchProtectionOption

	// in:body
	EditBranchProtectionOption api.EditBranchProtectionOption

	// in:body
	UpdateBranchProtectionPriories api.UpdateBranchProtectionPriories

	// in:body
	CreateOAuth2ApplicationOptions api.CreateOAuth2ApplicationOptions

	// in:body
	CreatePullReviewOptions api.CreatePullReviewOptions

	// in:body
	CreatePullReviewComment api.CreatePullReviewComment

	// in:body
	SubmitPullReviewOptions api.SubmitPullReviewOptions

	// in:body
	DismissPullReviewOptions api.DismissPullReviewOptions

	// in:body
	MigrateRepoOptions api.MigrateRepoOptions

	// in:body
	PullReviewRequestOptions api.PullReviewRequestOptions

	// in:body
	CreateTagOption api.CreateTagOption

	// in:body
	CreateTagProtectionOption api.CreateTagProtectionOption

	// in:body
	EditTagProtectionOption api.EditTagProtectionOption

	// in:body
	CreateAccessTokenOption api.CreateAccessTokenOption

	// in:body
	UserSettingsOptions api.UserSettingsOptions

	// in:body
	CreateWikiPageOptions api.CreateWikiPageOptions

	// in:body
	CreatePushMirrorOption api.CreatePushMirrorOption

	// in:body
	UpdateUserAvatarOptions api.UpdateUserAvatarOption

	// in:body
	UpdateRepoAvatarOptions api.UpdateRepoAvatarOption

	// in:body
	CreateOrUpdateSecretOption api.CreateOrUpdateSecretOption

	// in:body
	UserBadgeOption api.UserBadgeOption

	// in:body
	CreateVariableOption api.CreateVariableOption

	// in:body
	RenameOrgOption api.RenameOrgOption

	// in:body
	CreateActionWorkflowDispatch api.CreateActionWorkflowDispatch

	// in:body
	UpdateVariableOption api.UpdateVariableOption

	// in:body
	LockIssueOption api.LockIssueOption
}
